@@ -125,7 +125,7 @@ wb_check_overwrite_tables <- function(
 
 
 validate_cf_params <- function(params) {
-  bad <- names(params) %out% c("showValue", "gradient", "border", "percent", "rank")
+  bad <- names(params) %out% c("border", "gradient", "iconSet", "percent", "rank", "reverse", "showValue")
   if (any(bad)) {
     stop("Invalid parameters: ", toString(names(params)[bad]))
   }
