@@ -247,5 +247,6 @@ void write_xmlPtr(
     std::string fl
 ) {
   unsigned int pugi_format_flags = pugi::format_raw | pugi::format_no_escapes;
-  doc->save_file(fl.c_str(), "", pugi_format_flags, pugi::encoding_utf8);
+  const bool success = doc->save_file(fl.c_str(), "", pugi_format_flags, pugi::encoding_utf8);
+  if (!success) Rf_error("could not save file");
 }
