@@ -312,11 +312,23 @@ test_that("wb_add_data_table() is a wrapper", {
   expect_wrapper("add_data_table", wb = wb, params = list(sheet = 1, x = data.frame(x = 1)))
 })
 
+test_that("wb_add_pivot_table() is a wrapper", {
+  wb <- wb_workbook()$add_worksheet()$add_data(x = mtcars)
+  df <- wb_data(wb)
+  expect_wrapper("add_pivot_table", wb = wb, params = list(x = df, data = "disp"))
+})
+
 test_that("wb_add_formula() is a wrapper", {
   wb <- wb_workbook()$add_worksheet(1)
   expect_wrapper("add_formula",    wb = wb, params = list(sheet = 1, x = "=TODAY()"))
 })
 
+test_that("wb_copy_cells() is a wrapper", {
+  wb <- wb_workbook()$add_worksheet(1)$add_data(x = "1")
+  dat <- wb_data(wb, 1, dims = "A1", colNames = FALSE)
+  expect_wrapper("copy_cells",     wb = wb, params = list(sheet = 1, data = dat, dims = "B1"))
+})
+
 # wb_add_comment() --------------------------------------------------------
 
 test_that("wb_add_comment() is a wrapper", {
